==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this.withHttpQueryParameterName(instance.getHttpQueryParameterName()); 
  }
  private String httpQueryParameterName;
  public String getHttpQueryParameterName() {
    return this.httpQueryParameterName;
  }
  public A withHttpQueryParameterName(String httpQueryParameterName) {
    this.httpQueryParameterName=httpQueryParameterName; return (A) this;
  }
  public Boolean hasHttpQueryParameterName() {
    return this.httpQueryParameterName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl) o;
    if (httpQueryParameterName != null ? !httpQueryParameterName.equals(that.httpQueryParameterName) :that.httpQueryParameterName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpQueryParameterName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpQueryParameterName != null) { sb.append("httpQueryParameterName:"); sb.append(httpQueryParameterName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    if (instance != null) {
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
  }
  private String httpQueryParameterName;
  public String getHttpQueryParameterName() {
    return this.httpQueryParameterName;
  }
  public A withHttpQueryParameterName(String httpQueryParameterName) {
    this.httpQueryParameterName=httpQueryParameterName; return (A) this;
  }
  public Boolean hasHttpQueryParameterName() {
    return this.httpQueryParameterName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl) o;
    if (!java.util.Objects.equals(httpQueryParameterName, that.httpQueryParameterName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpQueryParameterName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpQueryParameterName != null) { sb.append("httpQueryParameterName:"); sb.append(httpQueryParameterName); }
    sb.append("}");
    return sb.toString();
  }
  
}
